==> django_advance_thumbnail-1.0.1.tar.gz: django_advance_thumbnail-1.0.1/django_advance_thumbnail/fields.py <==
import io
import os

from PIL import Image, ImageOps
from django.core.files import File
from django.db import models


class AdvanceThumbnailField(models.ImageField):
    def __init__(self, *args, **kwargs):
        self.source_field_name = kwargs.pop('source_field', None)
        self.size = kwargs.pop('size', (300, 300))
        super().__init__(*args, **kwargs)

    def contribute_to_class(self, cls, name, **kwargs):
        super().contribute_to_class(cls, name, **kwargs)
        models.signals.post_save.connect(self.create_thumbnail, sender=cls)

    def pre_save(self, model_instance, add):
        file = super().pre_save(model_instance, add)
        source_field = getattr(model_instance, self.source_field_name)
        if not source_field:
            file.delete(save=False)
        return file

    def create_thumbnail(self, instance, **kwargs):
        source_field = getattr(instance, self.source_field_name)
        if not source_field or not source_field.name:
            return
        # Disconnect the signal before creating and saving the thumbnail
        models.signals.post_save.disconnect(self.create_thumbnail, sender=instance.__class__)

        try:
            with source_field.open() as source_file:
                img = Image.open(source_file)

                # Handle orientation from EXIF data
                img = ImageOps.exif_transpose(img)

                img.thumbnail(self.size)

                filename, extension = os.path.splitext(os.path.basename(source_field.name))
                thumbnail_filename = f"{filename}_thumbnail{extension}"

                thumbnail_io = io.BytesIO()
                img.save(thumbnail_io, format=img.format)
                thumbnail_io.seek(0)

                thumbnail_file = File(thumbnail_io, name=thumbnail_filename)
                setattr(instance, self.name, thumbnail_file)

                instance.save(update_fields=[self.name])

        finally:
            # Reconnect the signal after saving
            models.signals.post_save.connect(self.create_thumbnail, sender=instance.__class__)

==> django_advance_thumbnail-1.0.2.tar.gz: django_advance_thumbnail-1.0.2/django_advance_thumbnail/fields.py <==
import io
import os

from PIL import Image, ImageOps
from django.core.files import File
from django.db import models


class AdvanceThumbnailField(models.ImageField):
    def __init__(self, *args, **kwargs):
        self.source_field_name = kwargs.pop('source_field', None)
        self.size = kwargs.pop('size', (300, 300))
        super().__init__(*args, **kwargs)

    def contribute_to_class(self, cls, name, **kwargs):
        super().contribute_to_class(cls, name, **kwargs)
        models.signals.post_save.connect(self.create_thumbnail, sender=cls)

    def pre_save(self, model_instance, add):
        file = super().pre_save(model_instance, add)
        source_field = getattr(model_instance, self.source_field_name)
        if not source_field:
            file.delete(save=False)
        return file

    def create_thumbnail(self, instance, **kwargs):
        source_field = getattr(instance, self.source_field_name)
        if not source_field or not source_field.name:
            return

        # Disconnect the signal before creating and saving the thumbnail
        models.signals.post_save.disconnect(self.create_thumbnail, sender=instance.__class__)

        try:
            with source_field.open() as source_file:
                img = Image.open(source_file)

                # Handle orientation from EXIF data
                img = ImageOps.exif_transpose(img)

                img.thumbnail(self.size)

                filename, extension = os.path.splitext(os.path.basename(source_field.name))
                thumbnail_filename = f"{filename}_thumbnail{extension}"

                thumbnail_io = io.BytesIO()

                # Determine the format based on the file extension, fallback to JPEG if not found
                if extension.lower() in ['.jpg', '.jpeg']:
                    image_format = 'JPEG'
                elif extension.lower() == '.png':
                    image_format = 'PNG'
                else:
                    image_format = 'JPEG'  # Default to JPEG if unsure

                img.save(thumbnail_io, format=image_format)
                thumbnail_io.seek(0)

                thumbnail_file = File(thumbnail_io, name=thumbnail_filename)
                setattr(instance, self.name, thumbnail_file)

                instance.save(update_fields=[self.name])

        finally:
            # Reconnect the signal after saving
            models.signals.post_save.connect(self.create_thumbnail, sender=instance.__class__)
